Struct mln_did::accounts::AddService
source · pub struct AddService {
pub did_data: Pubkey,
pub authority: Pubkey,
}Expand description
Generated client accounts for AddService.
Fields
did_data: PubkeyTrait Implementations
sourceimpl BorshSerialize for AddService
impl BorshSerialize for AddService
sourceimpl ToAccountMetas for AddService
impl ToAccountMetas for AddService
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for AddService
impl Send for AddService
impl Sync for AddService
impl Unpin for AddService
impl UnwindSafe for AddService