Struct mln_did::accounts::RemoveService
source · pub struct RemoveService {
pub did_data: Pubkey,
pub authority: Pubkey,
}Expand description
Generated client accounts for RemoveService.
Fields
did_data: PubkeyTrait Implementations
sourceimpl BorshSerialize for RemoveService
impl BorshSerialize for RemoveService
sourceimpl ToAccountMetas for RemoveService
impl ToAccountMetas for RemoveService
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for RemoveService
impl Send for RemoveService
impl Sync for RemoveService
impl Unpin for RemoveService
impl UnwindSafe for RemoveService