Struct mln_did::accounts::SetVmFlagsMethod
source · pub struct SetVmFlagsMethod {
pub did_data: Pubkey,
pub authority: Pubkey,
}Expand description
Generated client accounts for SetVmFlagsMethod.
Fields
did_data: PubkeyTrait Implementations
sourceimpl BorshSerialize for SetVmFlagsMethod
impl BorshSerialize for SetVmFlagsMethod
sourceimpl ToAccountMetas for SetVmFlagsMethod
impl ToAccountMetas for SetVmFlagsMethod
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for SetVmFlagsMethod
impl Send for SetVmFlagsMethod
impl Sync for SetVmFlagsMethod
impl Unpin for SetVmFlagsMethod
impl UnwindSafe for SetVmFlagsMethod