Struct mln_did::instruction::RemoveService
source · pub struct RemoveService {
pub fragment: String,
pub eth_signature: Option<Secp256k1RawSignature>,
}Expand description
Instruction.
Fields
fragment: Stringeth_signature: Option<Secp256k1RawSignature>Trait Implementations
sourceimpl BorshDeserialize for RemoveService
impl BorshDeserialize for RemoveService
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
sourceimpl BorshSerialize for RemoveService
impl BorshSerialize for RemoveService
sourceimpl Discriminator for RemoveService
impl Discriminator for RemoveService
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]
sourceimpl InstructionData for RemoveService
impl InstructionData for RemoveService